plone.app.event.dx.traverser — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.dx.traverser

class `plone.app.event.dx.traverser.` `OccurrenceTraverser`(context, request)

  Occurrence Traverser for Dexterity based contexts.

  Please note: here is not ImageTraverser support included, since accessing images is done by calling the @@images view.

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »